@@ -119,7 +119,7 @@ select_async_module_server <- function(id, common, parent_session, map) {
       common$logger %>% writeLog(result$message)
 
       # TRIGGER
-      gargoyle::trigger("select_async")
+      trigger("select_async")
 
       # explicitly call the mapping function
       do.call("select_async_module_map", list(map, common))
@@ -150,7 +150,7 @@ select_async_module_server <- function(id, common, parent_session, map) {
 }
 
 select_async_module_map <- function(map, common) {
-
+  req(common$raster)
   ex <- as.vector(terra::ext(common$raster))
   pal <- RColorBrewer::brewer.pal(9, "Greens")
   custom_greens <- colorRampPalette(pal)(10)
