@@ -8,6 +8,7 @@ modules <- data.frame(
   "result" = c(TRUE, FALSE, FALSE, FALSE),
   "rmd" = c(TRUE, TRUE, TRUE, TRUE),
   "save" = c(TRUE, TRUE, TRUE, TRUE),
+  "download" = c(FALSE, FALSE, TRUE, TRUE),
   "async" = c(TRUE, FALSE, FALSE, FALSE))
 
 common_objects = c("raster", "histogram", "scatter")
@@ -168,6 +169,7 @@ test_that("Check create template function works with false settings", {
     modules$result <- c(TRUE, FALSE, FALSE, FALSE)
     modules$rmd = c(FALSE, FALSE, FALSE, FALSE)
     modules$save = c(FALSE, FALSE, FALSE, FALSE)
+    modules$download = c(FALSE, FALSE, FALSE, FALSE)
     modules$async = c(FALSE, FALSE, FALSE, FALSE)
 
     directory <- tempfile()
@@ -179,8 +181,6 @@ test_that("Check create template function works with false settings", {
                     author = "Simon E. H. Smart", include_map = FALSE,
                     include_table = FALSE, include_code = FALSE, install = FALSE)
 
-
-
     expect_true(file.exists(file.path(directory, name, "inst", "shiny", "server.R")))
     expect_true(file.exists(file.path(directory, name, "inst", "shiny", "ui.R")))
     expect_true(file.exists(file.path(directory, name, "inst", "shiny", "global.R")))
@@ -212,6 +212,7 @@ test_that("Check async, no map runs correctly", {
       modules$result <- c(TRUE, FALSE, FALSE, FALSE)
       modules$rmd = c(FALSE, FALSE, FALSE, FALSE)
       modules$save = c(FALSE, FALSE, FALSE, FALSE)
+      modules$download = c(FALSE, FALSE, TRUE, TRUE)
       modules$async = c(TRUE, FALSE, FALSE, FALSE)
 
       directory <- tempfile()
@@ -236,27 +237,31 @@ test_that("Check async, no map runs correctly", {
 
 test_that("Check async, with map runs correctly", {
   if (suggests){
-    modules$map <- c(TRUE, FALSE, FALSE, FALSE)
-    modules$result <- c(TRUE, FALSE, FALSE, FALSE)
-    modules$rmd = c(FALSE, FALSE, FALSE, FALSE)
-    modules$save = c(FALSE, FALSE, FALSE, FALSE)
-    modules$async = c(TRUE, FALSE, FALSE, FALSE)
+    withr::with_temp_libpaths({
+      modules$map <- c(TRUE, FALSE, FALSE, FALSE)
+      modules$result <- c(TRUE, FALSE, FALSE, FALSE)
+      modules$rmd = c(FALSE, FALSE, FALSE, FALSE)
+      modules$save = c(FALSE, FALSE, FALSE, FALSE)
+      modules$download = c(FALSE, FALSE, TRUE, TRUE)
+      modules$async = c(TRUE, FALSE, FALSE, FALSE)
 
-    directory <- tempfile()
-    dir.create(directory, recursive = TRUE)
-    name <- "shinyscholard"
+      directory <- tempfile()
+      dir.create(directory, recursive = TRUE)
+      name <- "shinyscholard"
 
-    create_template(path = directory, name = name,
-                    common_objects = common_objects, modules = modules,
-                    author = "Simon E. H. Smart", include_map = TRUE,
-                    include_table = FALSE, include_code = TRUE, install = FALSE)
+      create_template(path = directory, name = name,
+                      common_objects = common_objects, modules = modules,
+                      author = "Simon E. H. Smart", include_map = TRUE,
+                      include_table = FALSE, include_code = TRUE, install = FALSE)
 
-    devtools::document(file.path(directory, name))
-    devtools::install(file.path(directory, name), force = TRUE, quick = TRUE, dependencies = FALSE)
+      devtools::document(file.path(directory, name))
+      devtools::install(file.path(directory, name), force = TRUE, quick = TRUE, dependencies = FALSE)
 
-    app <- shinytest2::AppDriver$new(app_dir = file.path(directory, name, "inst", "shiny"), name = "create_test")
-    common <- app$get_value(export = "common")
-    expect_true(is.null(common$raster))
-    app$stop()
+      app <- shinytest2::AppDriver$new(app_dir = file.path(directory, name, "inst", "shiny"), name = "create_test")
+      common <- app$get_value(export = "common")
+      expect_true(is.null(common$raster))
+      app$stop()
+    })
   }
 })
+
